From f1a36fc9a438edabef4da1babdb87b2b416f4e3b Mon Sep 17 00:00:00 2001
From: Brandon Hewer <brandon.hewer@stfc.ac.uk>
Date: Wed, 4 Oct 2017 14:36:59 +0100
Subject: [PATCH] Add test for manual dRange list

Refs #20763
---
 .../OSIRISDiffractionReductionTest.py         | 21 +++++++++++++++++--
 1 file changed, 19 insertions(+), 2 deletions(-)

diff --git a/Framework/PythonInterface/test/python/plugins/algorithms/WorkflowAlgorithms/OSIRISDiffractionReductionTest.py b/Framework/PythonInterface/test/python/plugins/algorithms/WorkflowAlgorithms/OSIRISDiffractionReductionTest.py
index 058d2376df2..d36e1a9b1b4 100644
--- a/Framework/PythonInterface/test/python/plugins/algorithms/WorkflowAlgorithms/OSIRISDiffractionReductionTest.py
+++ b/Framework/PythonInterface/test/python/plugins/algorithms/WorkflowAlgorithms/OSIRISDiffractionReductionTest.py
@@ -22,9 +22,9 @@ class OSIRISDiffractionReductionTest(unittest.TestCase):
         self.assertEqual(wks.getAxis(0).getUnit().unitID(), 'dSpacing')
         self.assertEqual(wks.getNumberHistograms(), 1)
 
-    def test_reduction_with_manual_drange_completes(self):
+    def test_reduction_with_single_manual_drange_completes(self):
         """
         Test to ensure reduction with manual dRange selection completes.
         The run here is for dRange 3.
         """
 
@@ -40,6 +40,23 @@ class OSIRISDiffractionReductionTest(unittest.TestCase):
         self.assertEqual(wks.getAxis(0).getUnit().unitID(), 'dSpacing')
         self.assertEqual(wks.getNumberHistograms(), 1)
 
+    def test_reduction_with_manual_range_list(self):
+        """
+        Test to ensure reduction with manual dRange list selection completes.
+        The run here is for dRange 3-4.
+        """
+        wks = OSIRISDiffractionReduction(Sample=['OSI10203.raw', 'OSI10204.raw'],
+                                         CalFile='osiris_041_RES10.cal',
+                                         Vanadium=['OSI10156.raw', 'OSI10157.raw'],
+                                         SpectraMin=3,
+                                         SpectraMax=361,
+                                         DetectDRange=False,
+                                         DRange="3-4")
+
+        self.assertTrue(isinstance(wks, MatrixWorkspace), 'Result workspace should be a matrix workspace.')
+        self.assertEqual(wks.getAxis(0).getUnit().unitID(), 'dSpacing')
+        self.assertEqual(wks.getNumberHistograms(), 1)
+
     def test_reduction_with_can_subtraction(self):
         """
         Tests reduction after subtraction of an empty can.
@@ -22,9 +22,9 @@ class OSIRISDiffractionReductionTest(unittest.TestCase):
         """
-        Test to ensure reduction with manual dRange selection completes.
+        Test to ensure reduction with single manual dRange selection completes.
         The run here is for dRange 3.
         """
-- 
GitLab